package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcNetworkMqPrincipal;

/**
 * 网络民情责任人Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface TcNetworkMqPrincipalMapper 
{
    /**
     * 查询网络民情责任人
     * 
     * @param id 网络民情责任人主键
     * @return 网络民情责任人
     */
    public TcNetworkMqPrincipal selectTcNetworkMqPrincipalById(Long id);

    /**
     * 查询网络民情责任人列表
     * 
     * @param tcNetworkMqPrincipal 网络民情责任人
     * @return 网络民情责任人集合
     */
    public List<TcNetworkMqPrincipal> selectTcNetworkMqPrincipalList(TcNetworkMqPrincipal tcNetworkMqPrincipal);

    /**
     * 新增网络民情责任人
     * 
     * @param tcNetworkMqPrincipal 网络民情责任人
     * @return 结果
     */
    public int insertTcNetworkMqPrincipal(TcNetworkMqPrincipal tcNetworkMqPrincipal);

    /**
     * 修改网络民情责任人
     * 
     * @param tcNetworkMqPrincipal 网络民情责任人
     * @return 结果
     */
    public int updateTcNetworkMqPrincipal(TcNetworkMqPrincipal tcNetworkMqPrincipal);

    /**
     * 删除网络民情责任人
     * 
     * @param id 网络民情责任人主键
     * @return 结果
     */
    public int deleteTcNetworkMqPrincipalById(Long id);

    /**
     * 批量删除网络民情责任人
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcNetworkMqPrincipalByIds(Long[] ids);
}
